@@ -24,7 +24,7 @@
 #' @param subset An optional vector specifying a subset of studies to
 #'   be used.
 #' @param inactive A character string defining the inactive treatment
-#'   (see Details).
+#'   component (see Details).
 #' @param sep.comps A single character to define separator between
 #'   treatment components.
 #' @param C.matrix C matrix (see Details).
@@ -33,13 +33,14 @@
 #'   \code{"HR"}, \code{"MD"}, \code{"SMD"}, or \code{"ROM"}.
 #' @param level The level used to calculate confidence intervals for
 #'   individual comparisons.
-#' @param level.comb The level used to calculate confidence intervals
-#'   for pooled estimates.
-#' @param comb.fixed A logical indicating whether a fixed effects
-#'   (common effects) network meta-analysis should be conducted.
-#' @param comb.random A logical indicating whether a random effects
+#' @param level.ma The level used to calculate confidence intervals
+#'   for network estimates.
+#' @param fixed A logical indicating whether a fixed effects / common
+#'   effects network meta-analysis should be conducted.
+#' @param random A logical indicating whether a random effects
 #'   network meta-analysis should be conducted.
-#' @param reference.group Reference treatment.
+#' @param reference.group Reference treatment (first treatment is used
+#'   if argument is missing).
 #' @param baseline.reference A logical indicating whether results
 #'   should be expressed as comparisons of other treatments versus the
 #'   reference treatment (default) or vice versa. This argument is
@@ -53,7 +54,8 @@
 #'   design.
 #' @param tol.multiarm.se A numeric for the tolerance for consistency
 #'   of standard errors in multi-arm studies which are consistent by
-#'   design.
+#'   design. This check is not conducted if the argument is
+#'   \code{NULL}.
 #' @param details.chkmultiarm A logical indicating whether treatment
 #'   estimates and / or variances of multi-arm studies with
 #'   inconsistent results or negative multi-arm variances should be
@@ -67,12 +69,18 @@
 #'   \code{backtransf = TRUE}, results for \code{sm = "OR"} are
 #'   presented as odds ratios rather than log odds ratios, for
 #'   example.
-#' @param nchar.trts A numeric defining the minimum number of
-#'   characters used to create unique treatment names (see Details).
+#' @param nchar.comps A numeric defining the minimum number of
+#'   characters used to create unique names for components (see
+#'   Details).
 #' @param title Title of meta-analysis / systematic review.
 #' @param warn A logical indicating whether warnings should be printed
 #'   (e.g., if studies are excluded from meta-analysis due to zero
 #'   standard errors).
+#' @param warn.deprecated A logical indicating whether warnings should
+#'   be printed if deprecated arguments are used.
+#' @param nchar.trts Deprecated argument (replaced by
+#'   \code{nchar.comps}).
+#' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
 #' Treatments in network meta-analysis (NMA) can be complex
@@ -93,7 +101,7 @@
 #' 
 #' The additive CNMA model has been implemented using Bayesian methods
 #' (Mills et al., 2012; Welton et al., 2013). This function implements
-#' the additive model in a frequentist way (Rücker et al., 2019).
+#' the additive model in a frequentist way (Rücker et al., 2020).
 #' 
 #' The underlying multivariate model is given by
 #' 
@@ -127,6 +135,25 @@
 #' calculated internally from treatment names. However, it is possible
 #' to specify a different matrix using argument \code{C.matrix}.
 #' 
+#' By default, component names are not abbreviated in
+#' printouts. However, in order to get more concise printouts,
+#' argument \code{nchar.comps} can be used to define the minimum
+#' number of characters for abbreviated component names (see
+#' \code{\link{abbreviate}}, argument \code{minlength}). R function
+#' \code{\link{treats}} is utilised internally to create abbreviated
+#' component names.
+#' 
+#' @note
+#' This function calculates effects for individual components and
+#' complex interventions present in the network.
+#'
+#' R function \code{\link{netcomplex}} can be used to calculate the
+#' effect for arbitrary complex interventions in a component network
+#' meta-analysis. Furthermore, R function \code{\link{netcomparison}}
+#' can be used to calculate the effect for comparisons of two
+#' arbitrary complex intervention in a component network
+#' meta-analysis.
+#' 
 #' @return
 #' An object of classes \code{discomb} and \code{netcomb} with
 #' corresponding \code{print}, \code{summary}, and \code{forest}
@@ -138,8 +165,8 @@
 #' \item{TE}{Estimate of treatment effect, i.e. difference between
 #'   first and second treatment.}
 #' \item{seTE}{Standard error of treatment estimate.}
-#' \item{seTE.adj}{Standard error of treatment estimate, adjusted for
-#'   multi-arm studies.}
+#' \item{seTE.adj.fixed, seTE.adj.random}{Standard error of treatment
+#'   estimate, adjusted for multi-arm studies.}
 #' \item{event1}{Number of events in first treatment group.}
 #' \item{event2}{Number of events in second treatment group.}
 #' \item{n1}{Number of observations in first treatment group.}
@@ -242,12 +269,12 @@
 #' \item{B.matrix}{Edge-vertex incidence matrix (\emph{m}x\emph{n}).}
 #' \item{C.matrix}{As defined above.}
 #' \item{sm}{Summary measure.}
-#' \item{level.comb}{Level for confidence intervals.}
-#' \item{comb.fixed, comb.random, tau.preset}{As defined above.}
+#' \item{level.ma}{Level for confidence intervals.}
+#' \item{fixed, random, tau.preset}{As defined above.}
 #' \item{sep.trts}{A character used in comparison names as separator
 #'   between treatment labels.}
-#' \item{nchar.trts}{A numeric defining the minimum number of
-#'   characters used to create unique treatment and component names.}
+#' \item{nchar.comps}{A numeric defining the minimum number of
+#'   characters used to create unique component names.}
 #' \item{inactive, sep.comps}{As defined above.}
 #' \item{backtransf}{A logical indicating whether results should be
 #'   back transformed in printouts and forest plots.}
@@ -260,8 +287,10 @@
 #' @author Gerta Rücker \email{ruecker@@imbi.uni-freiburg.de}, Guido
 #'   Schwarzer \email{sc@@imbi.uni-freiburg.de}
 #' 
-#' @seealso \link{netcomb}, \link{forest.netcomb},
-#'   \link{summary.netcomb}, \link{netmeta}, \link{netconnection}
+#' @seealso \code{\link{netcomb}}, \code{\link{forest.netcomb}},
+#'   \code{\link{summary.netcomb}}, \code{\link{netmeta}},
+#'   \code{\link{netconnection}}, \code{\link{netcomplex}},
+#'   \code{\link{netcomparison}}
 #' 
 #' @references
 #' König J, Krahn U, Binder H (2013):
@@ -276,10 +305,10 @@
 #' \emph{Journal of Clinical Epidemiology},
 #' \bold{65}, 1282--8
 #' 
-#' Rücker G, Petropoulou M, Schwarzer G (2019):
+#' Rücker G, Petropoulou M, Schwarzer G (2020):
 #' Network meta-analysis of multicomponent interventions.
 #' \emph{Biometrical Journal},
-#' 1--14, https://doi.org/10.1002/bimj.201800167
+#' \bold{62}, 808--21
 #' 
 #' Welton NJ, Caldwell DM, Adamopoulos E, Vedhara K (2009):
 #' Mixed treatment comparison meta-analysis of complex interventions:
@@ -351,29 +380,31 @@ discomb <- function(TE, seTE,
                     ##
                     sm,
                     level = gs("level"),
-                    level.comb = gs("level.comb"),
-                    comb.fixed = gs("comb.fixed"),
-                    comb.random = gs("comb.random") | !is.null(tau.preset),
+                    level.ma = gs("level.ma"),
+                    fixed = gs("fixed"),
+                    random = gs("random") | !is.null(tau.preset),
                     ##
-                    reference.group = "",
+                    reference.group,
                     baseline.reference = TRUE,
                     seq = NULL,
                     ##
                     tau.preset = NULL,
                     ##
                     tol.multiarm = 0.001,
-                    tol.multiarm.se = tol.multiarm,
+                    tol.multiarm.se = NULL,
                     details.chkmultiarm = FALSE,
                     ##
                     details.chkident = FALSE,
                     ##
                     sep.trts = ":",
-                    nchar.trts = 666,
+                    nchar.comps = 666,
                     ##
                     backtransf = gs("backtransf"),
                     ##
                     title = "",
-                    warn = TRUE) {
+                    warn = TRUE, warn.deprecated = gs("warn.deprecated"),
+                    nchar.trts = nchar.comps,
+                    ...) {
   
   
   ##
@@ -381,41 +412,55 @@ discomb <- function(TE, seTE,
   ## (1) Check arguments
   ##
   ##
-  chkchar <- meta:::chkchar
-  chklevel <- meta:::chklevel
-  chklogical <- meta:::chklogical
-  chknumeric <- meta:::chknumeric
-  ##
   chkchar(sep.comps, nchar = 1, length = 1)
   ##
   chklevel(level)
-  chklevel(level.comb)
-  ##
-  chklogical(comb.fixed)
-  chklogical(comb.random)
   ##
   missing.reference.group <- missing(reference.group) 
-  if (missing.reference.group)
-    reference.group <- ""
   chklogical(baseline.reference)
   ##
   if (!is.null(tau.preset))
     chknumeric(tau.preset, min = 0, length = 1)
   ##
   chknumeric(tol.multiarm, min = 0, length = 1)
-  chknumeric(tol.multiarm.se, min = 0, length = 1)
+  if (!is.null(tol.multiarm.se))
+    chknumeric(tol.multiarm.se, min = 0, length = 1)
   chklogical(details.chkmultiarm)
   ##
   chklogical(details.chkident)
   ##
   missing.sep.trts <- missing(sep.trts)
   chkchar(sep.trts)
-  chknumeric(nchar.trts, min = 1, length = 1)
   ##
   chklogical(backtransf)
   ##
   chkchar(title)
   chklogical(warn)
+  ##
+  ## Check for deprecated arguments in '...'
+  ##
+  args  <- list(...)
+  chklogical(warn.deprecated)
+  ##
+  level.ma <- deprecated(level.ma, missing(level.ma), args, "level.comb",
+                         warn.deprecated)
+  chklevel(level.ma)
+  ##
+  missing.fixed <- missing(fixed)
+  fixed <- deprecated(fixed, missing.fixed, args, "comb.fixed",
+                      warn.deprecated)
+  chklogical(fixed)
+  ##
+  random <-
+    deprecated(random, missing(random), args, "comb.random", warn.deprecated)
+  chklogical(random)
+  ##
+  nchar.comps <-
+    deprecated2(nchar.comps, missing(nchar.comps),
+                nchar.trts, missing(nchar.trts),
+                warn.deprecated)
+  nchar.comps <- replaceNULL(nchar.comps, 666)
+  chknumeric(nchar.comps, min = 1, length = 1)
   
   
   ##
@@ -435,7 +480,7 @@ discomb <- function(TE, seTE,
   TE <- eval(mf[[match("TE", names(mf))]],
              data, enclos = sys.frame(sys.parent()))
   ##
-  if (inherits(TE, "pairwise")) {
+  if (is.data.frame(TE) & !is.null(attr(TE, "pairwise"))) {
     is.pairwise <- TRUE
     ##
     sm <- attr(TE, "sm")
@@ -563,6 +608,11 @@ discomb <- function(TE, seTE,
       seq <- as.character(seq)
   }
   ##
+  ## Check value for reference group
+  ##
+  if (missing.reference.group)
+    reference.group <- labels[1]
+  ##
   if (reference.group != "")
     reference.group <- setref(reference.group, labels)
   
@@ -593,10 +643,6 @@ discomb <- function(TE, seTE,
   ##
   ## Check for correct number of comparisons
   ##
-  is.wholenumber <-
-    function(x, tol = .Machine$double.eps^0.5)
-      abs(x - round(x)) < tol
-  ##
   tabnarms <- table(studlab)
   sel.narms <- !is.wholenumber((1 + sqrt(8 * tabnarms + 1)) / 2)
   ##
@@ -688,6 +734,7 @@ discomb <- function(TE, seTE,
   ##
   if (missing(C.matrix)) {
     C.matrix <- createC(netc, sep.comps, inactive)
+    inactive <- attr(C.matrix, "inactive")
     C.matrix <- C.matrix[labels, , drop = FALSE]
   }
   else {
@@ -700,10 +747,16 @@ discomb <- function(TE, seTE,
     if (is.null(rownames(C.matrix)))
       wrong.labels <- TRUE
     else {
-      if (length(unique(labels)) == length(unique(tolower(labels)))) 
+      if (length(unique(labels)) ==
+          length(unique(tolower(labels))) &&
+          length(unique(rownames(C.matrix))) ==
+          length(unique(tolower(rownames(C.matrix))))
+          )
         idx <- charmatch(tolower(rownames(C.matrix)), 
                          tolower(labels), nomatch = NA)
-      else idx <- charmatch(rownames(C.matrix), labels, nomatch = NA)
+      else
+        idx <- charmatch(rownames(C.matrix), labels, nomatch = NA)
+      ##
       if (any(is.na(idx)) || any(idx == 0)) 
         wrong.labels <- TRUE
     }
@@ -817,7 +870,7 @@ discomb <- function(TE, seTE,
   
   
   res.f <- nma.additive(p0$TE[o], p0$weights[o], p0$studlab[o],
-                        p0$treat1[o], p0$treat2[o], level.comb,
+                        p0$treat1[o], p0$treat2[o], level.ma,
                         X.matrix, C.matrix, B.matrix,
                         Q, df.Q.additive, df.Q.diff,
                         n, sep.trts)
@@ -844,7 +897,7 @@ discomb <- function(TE, seTE,
   p1 <- prepare(TE, seTE, treat1, treat2, studlab, tau)
   ##
   res.r <- nma.additive(p1$TE[o], p1$weights[o], p1$studlab[o],
-                        p1$treat1[o], p1$treat2[o], level.comb,
+                        p1$treat1[o], p1$treat2[o], level.ma,
                         X.matrix, C.matrix, B.matrix,
                         Q, df.Q.additive, df.Q.diff,
                         n, sep.trts)
@@ -869,6 +922,8 @@ discomb <- function(TE, seTE,
               TE = p0$TE[o],
               seTE = p0$seTE[o],
               seTE.adj = sqrt(1 / p0$weights[o]),
+              seTE.adj.fixed = sqrt(1 / p0$weights[o]),
+              seTE.adj.random = sqrt(1 / p1$weights[o]),
               ##
               design = designs$design[o],
               ##
@@ -990,15 +1045,23 @@ discomb <- function(TE, seTE,
               B.matrix = B.matrix,
               C.matrix = C.matrix,
               ##
+              L.matrix.fixed = res.f$L.matrix,
+              Lplus.matrix.fixed = res.f$Lplus.matrix,
+              L.matrix.random = res.r$L.matrix,
+              Lplus.matrix.random = res.r$Lplus.matrix,
+              ##
+              H.matrix.fixed = res.f$H.matrix[o, o],
+              H.matrix.random = res.r$H.matrix[o, o],
+              ##
               n.matrix = NA,
               events.matrix = NA,
               ##
               sm = sm,
               method = "Inverse",
               level = level,
-              level.comb = level.comb,
-              comb.fixed = comb.fixed,
-              comb.random = comb.random, 
+              level.ma = level.ma,
+              fixed = fixed,
+              random = random, 
               ##
               reference.group = reference.group,
               baseline.reference = baseline.reference,
@@ -1008,7 +1071,7 @@ discomb <- function(TE, seTE,
               tau.preset = tau.preset,
               ##
               sep.trts = sep.trts,
-              nchar.trts = nchar.trts,
+              nchar.comps = nchar.comps,
               ##
               inactive = inactive,
               sep.comps = sep.comps,
