@@ -10,18 +10,24 @@
 #' 
 #' @param x An object of class \code{netmeta}.
 #' @param inactive A character string defining the inactive treatment
-#'   (see Details).
+#'   component (see Details).
 #' @param sep.comps A single character to define separator between
 #'   treatment components.
 #' @param C.matrix C matrix (see Details).
-#' @param comb.fixed A logical indicating whether a fixed effects
-#'   (common effects) network meta-analysis should be conducted.
-#' @param comb.random A logical indicating whether a random effects
-#'   network meta-analysis should be conducted.
+#' @param fixed A logical indicating whether a fixed effects / common
+#'   effects network meta-analysis should be conducted.
+#' @param random A logical indicating whether a random effects network
+#'   meta-analysis should be conducted.
 #' @param tau.preset An optional value for the square-root of the
 #'   between-study variance \eqn{\tau^2}.
 #' @param details.chkident A logical indicating whether details on
 #'   unidentifiable components should be printed.
+#' @param nchar.comps A numeric defining the minimum number of
+#'   characters used to create unique names for components (see
+#'   Details).
+#' @param warn.deprecated A logical indicating whether warnings should
+#'   be printed if deprecated arguments are used.
+#' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
 #' Treatments in network meta-analysis (NMA) can be complex
@@ -38,7 +44,7 @@
 #' 
 #' The additive CNMA model has been implemented using Bayesian methods
 #' (Mills et al., 2012; Welton et al., 2013). This function implements
-#' the additive model in a frequentist way (Rücker et al., 2019).
+#' the additive model in a frequentist way (Rücker et al., 2020).
 #' 
 #' The underlying multivariate model is given by
 #' 
@@ -70,6 +76,25 @@
 #' between individual components. By default, the matrix \strong{C} is
 #' calculated internally from treatment names. However, it is possible
 #' to specify a different matrix using argument \code{C.matrix}.
+#' 
+#' By default, component names are not abbreviated in
+#' printouts. However, in order to get more concise printouts,
+#' argument \code{nchar.comps} can be used to define the minimum
+#' number of characters for abbreviated component names (see
+#' \code{\link{abbreviate}}, argument \code{minlength}). R function
+#' \code{\link{treats}} is utilised internally to create abbreviated
+#' component names.
+#' 
+#' @note
+#' This function calculates effects for individual components and
+#' complex interventions present in the network.
+#'
+#' R function \code{\link{netcomplex}} can be used to calculate the
+#' effect for arbitrary complex interventions in a component network
+#' meta-analysis. Furthermore, R function \code{\link{netcomparison}}
+#' can be used to calculate the effect for comparisons of two
+#' arbitrary complex intervention in a component network
+#' meta-analysis.
 #'
 #' @return
 #' An object of class \code{netcomb} with corresponding \code{print},
@@ -81,8 +106,8 @@
 #' \item{TE}{Estimate of treatment effect, i.e. difference between
 #'   first and second treatment.}
 #' \item{seTE}{Standard error of treatment estimate.}
-#' \item{seTE.adj}{Standard error of treatment estimate, adjusted for
-#'   multi-arm studies.}
+#' \item{seTE.adj.fixed, seTE.adj.random}{Standard error of treatment
+#'   estimate, adjusted for multi-arm studies.}
 #' \item{design}{Design of study providing pairwise comparison.}
 #' \item{event1}{Number of events in first treatment group.}
 #' \item{event2}{Number of events in second treatment group.}
@@ -177,8 +202,8 @@
 #' \item{pval.Comp.fixed, pval.Comp.random}{A vector with p-values for
 #'   the overall effect of components (fixed and random effects
 #'   model).}
-#' \item{Comb.fixed, Comb.random}{A vector of combination effects (fixed
-#'   and random effects model).}
+#' \item{Comb.fixed, Comb.random}{A vector of combination effects
+#'   (fixed and random effects model).}
 #' \item{seComb.fixed, seComb.random}{A vector with corresponding
 #'   standard errors (fixed and random effects model).}
 #' \item{lower.Comb.fixed, lower.Comb.random}{A vector with lower
@@ -187,9 +212,9 @@
 #' \item{upper.Comb.fixed, upper.Comb.random}{A vector with upper
 #'   confidence limits for combinations (fixed and random effects
 #'   model).}
-#' \item{statistic.Comb.fixed, statistic.Comb.random}{A vector with z-values for
-#'   the overall effect of combinations (fixed and random effects
-#'   model).}
+#' \item{statistic.Comb.fixed, statistic.Comb.random}{A vector with
+#'   z-values for the overall effect of combinations (fixed and random
+#'   effects model).}
 #' \item{pval.Comb.fixed, pval.Comb.random}{A vector with p-values for
 #'   the overall effect of combinations (fixed and random effects
 #'   model).}
@@ -218,12 +243,12 @@
 #' \item{B.matrix}{Edge-vertex incidence matrix (\emph{m}x\emph{n}).}
 #' \item{C.matrix}{As defined above.}
 #' \item{sm}{Summary measure.}
-#' \item{level.comb}{Level for confidence intervals.}
-#' \item{comb.fixed, comb.random, tau.preset}{As defined above.}
+#' \item{level.ma}{Level for confidence intervals.}
+#' \item{fixed, random, tau.preset}{As defined above.}
 #' \item{sep.trts}{A character used in comparison names as separator
 #'   between treatment labels.}
-#' \item{nchar.trts}{A numeric defining the minimum number of
-#'   characters used to create unique treatment and component names.}
+#' \item{nchar.comps}{A numeric defining the minimum number of
+#'   characters used to create unique component names.}
 #' \item{inactive, sep.comps}{As defined above.}
 #' \item{backtransf}{A logical indicating whether results should be
 #'   back transformed in printouts and forest plots.}
@@ -236,8 +261,9 @@
 #' @author Gerta Rücker \email{ruecker@@imbi.uni-freiburg.de}, Guido
 #'   Schwarzer \email{sc@@imbi.uni-freiburg.de}
 #' 
-#' @seealso \link{discomb}, \link{netmeta}, \link{forest.netcomb},
-#'   \link{print.netcomb}
+#' @seealso \code{\link{discomb}}, \code{\link{netmeta}},
+#'   \code{\link{forest.netcomb}}, \code{\link{print.netcomb}},
+#'   \code{\link{netcomplex}}, \code{\link{netcomparison}}
 #' 
 #' @references
 #' König J, Krahn U, Binder H (2013):
@@ -252,10 +278,10 @@
 #' \emph{Journal of Clinical Epidemiology},
 #' \bold{65}, 1282--8
 #' 
-#' Rücker G, Petropoulou M, Schwarzer G (2019):
+#' Rücker G, Petropoulou M, Schwarzer G (2020):
 #' Network meta-analysis of multicomponent interventions.
 #' \emph{Biometrical Journal},
-#' 1--14, https://doi.org/10.1002/bimj.201800167
+#' \bold{62}, 808--21
 #' 
 #' Welton NJ, Caldwell DM, Adamopoulos E, Vedhara K (2009):
 #' Mixed treatment comparison meta-analysis of complex interventions:
@@ -275,15 +301,15 @@
 #' #
 #' net1 <- netmeta(lnOR, selnOR, treat1, treat2, id,
 #'                 data = face, ref = "placebo",
-#'                 sm = "OR", comb.fixed = FALSE)
-#' summary(net1)
+#'                 sm = "OR", fixed = FALSE)
+#' net1
 #' forest(net1, xlim = c(0.2, 50))
 #' 
 #' # Additive model for treatment components (with placebo as inactive
 #' # treatment)
 #' #
 #' nc1 <- netcomb(net1, inactive = "placebo")
-#' summary(nc1)
+#' nc1
 #' forest(nc1, xlim = c(0.2, 50))
 #' 
 #' \dontrun{
@@ -307,15 +333,15 @@
 #' net1 <- netmeta(lnOR, selnOR, treat1, treat2, id,
 #'                 data = Linde2016, ref = "placebo",
 #'                 seq = trts,
-#'                 sm = "OR", comb.fixed = FALSE)
-#' summary(net1)
+#'                 sm = "OR", fixed = FALSE)
+#' net1
 #' forest(net1, xlim = c(0.2, 50))
 #' 
 #' # Additive model for treatment components (with placebo as inactive
 #' # treatment)
 #' #
 #' nc1 <- netcomb(net1, inactive = "placebo")
-#' summary(nc1)
+#' nc1
 #' forest(nc1, xlim = c(0.2, 50))
 #' }
 #' 
@@ -326,10 +352,14 @@ netcomb <- function(x,
                     inactive = NULL,
                     sep.comps = "+",
                     C.matrix,
-                    comb.fixed = x$comb.fixed,
-                    comb.random = x$comb.random | !is.null(tau.preset),
+                    fixed = x$fixed,
+                    random = x$random | !is.null(tau.preset),
                     tau.preset = NULL,
-                    details.chkident = FALSE) {
+                    details.chkident = FALSE,
+                    nchar.comps = x$nchar.trts,
+                    ##
+                    warn.deprecated = gs("warn.deprecated"),
+                    ...) {
   
   
   ##
@@ -337,19 +367,32 @@ netcomb <- function(x,
   ## (1) Check arguments
   ##
   ##
-  meta:::chkclass(x, "netmeta")
+  chkclass(x, "netmeta")
   ##
-  x <- upgradenetmeta(x)
+  x <- updateversion(x)
   ##
-  meta:::chkchar(sep.comps, nchar = 1, length = 1)
-  ##
-  meta:::chklogical(comb.fixed)
-  meta:::chklogical(comb.random)
+  chkchar(sep.comps, nchar = 1, length = 1)
   ##
   if (!is.null(tau.preset))
-    meta:::chknumeric(tau.preset, min = 0, length = 1)
+    chknumeric(tau.preset, min = 0, length = 1)
   ##
-  meta:::chklogical(details.chkident)
+  chklogical(details.chkident)
+  nchar.comps <- replaceNULL(nchar.comps, 666)
+  chknumeric(nchar.comps, min = 1, length = 1)
+  ##
+  ## Check for deprecated arguments in '...'
+  ##
+  args  <- list(...)
+  chklogical(warn.deprecated)
+  ##
+  missing.fixed <- missing(fixed)
+  fixed <- deprecated(fixed, missing.fixed, args, "comb.fixed",
+                      warn.deprecated)
+  chklogical(fixed)
+  ##
+  random <-
+    deprecated(random, missing(random), args, "comb.random", warn.deprecated)
+  chklogical(random)
   
   
   ##
@@ -380,8 +423,9 @@ netcomb <- function(x,
     ##
     ## Create C-matrix from netmeta object
     ##
-    C.matrix <- as.matrix(createC(x, sep.comps, inactive))
-    C.matrix <- C.matrix[trts, , drop = FALSE]
+    C.matrix <- createC(x, sep.comps, inactive)
+    inactive <- attr(C.matrix, "inactive")
+    C.matrix <- as.matrix(C.matrix)[trts, , drop = FALSE]
   }
   else {
     ##
@@ -403,7 +447,11 @@ netcomb <- function(x,
     if (is.null(rownames(C.matrix)))
       wrong.labels <- TRUE
     else {
-      if (length(unique(trts)) == length(unique(tolower(trts))))
+      if (length(unique(trts)) ==
+          length(unique(tolower(trts))) &&
+          length(unique(rownames(C.matrix))) ==
+          length(unique(tolower(rownames(C.matrix))))
+          )
         idx <- charmatch(tolower(rownames(C.matrix)),
                          tolower(trts), nomatch = NA)
       else
@@ -465,11 +513,11 @@ netcomb <- function(x,
       warning(paste0("The following component",
                      if (length(sel.ident) > 1)
                        "s are " else " is ",
-                     "not identifiable: ",
+                     "not uniquely identifiable: ",
                      paste(paste0("'", sel.ident, "'"),
                            collapse = ", "),
                      if (!details.chkident)
-                       paste("\nFor more details, re-run discomb()",
+                       paste("\nFor more details, re-run netcomb()",
                              "with argument details.chkident = TRUE.")),
               call. = FALSE)
       ##
@@ -486,9 +534,6 @@ netcomb <- function(x,
   ##
   df.Q.additive <- x$df.Q + x$n - 1 - qr(X.matrix)$rank
   ##
-  if (is.null(x$tol.multiarm.se))
-    x$tol.multiarm.se <- x$tol.multiarm
-  ##
   net <- netmeta(TE, seTE, treat1, treat2, studlab,
                  tol.multiarm = x$tol.multiarm,
                  tol.multiarm.se = x$tol.multiarm.se,
@@ -502,7 +547,7 @@ netcomb <- function(x,
   
   
   res.f <- nma.additive(p0$TE[o], p0$weights[o], p0$studlab[o],
-                        p0$treat1[o], p0$treat2[o], x$level.comb,
+                        p0$treat1[o], p0$treat2[o], x$level.ma,
                         X.matrix, C.matrix, B.matrix,
                         Q, df.Q.additive, df.Q.diff,
                         x$n, x$sep.trts)
@@ -530,7 +575,7 @@ netcomb <- function(x,
   ##
   p1 <- prepare(TE, seTE, treat1, treat2, studlab, tau)
   res.r <- nma.additive(p1$TE[o], p1$weights[o], p1$studlab[o],
-                        p1$treat1[o], p1$treat2[o], x$level.comb,
+                        p1$treat1[o], p1$treat2[o], x$level.ma,
                         X.matrix, C.matrix, B.matrix,
                         Q, df.Q.additive, df.Q.diff,
                         x$n, x$sep.trts)
@@ -543,6 +588,8 @@ netcomb <- function(x,
               TE = x$TE,
               seTE = x$seTE,
               seTE.adj = x$seTE.adj,
+              seTE.adj.fixed = x$seTE.adj.fixed,
+              seTE.adj.random = x$seTE.adj.random,
               ##
               design = x$design,
               ##
@@ -664,6 +711,14 @@ netcomb <- function(x,
               B.matrix = B.matrix,
               C.matrix = C.matrix,
               ##
+              L.matrix.fixed = res.f$L.matrix,
+              Lplus.matrix.fixed = res.f$Lplus.matrix,
+              L.matrix.random = res.r$L.matrix,
+              Lplus.matrix.random = res.r$Lplus.matrix,
+              ##
+              H.matrix.fixed = res.f$H.matrix[o, o],
+              H.matrix.random = res.r$H.matrix[o, o],
+              ##
               n.matrix = x$n.matrix,
               events.matrix = x$events.matrix,
               ##
@@ -673,9 +728,9 @@ netcomb <- function(x,
               sm = x$sm,
               method = "Inverse",
               level = x$level,
-              level.comb = x$level.comb,
-              comb.fixed = x$comb.fixed,
-              comb.random = x$comb.random,
+              level.ma = x$level.ma,
+              fixed = x$fixed,
+              random = x$random,
               ##
               reference.group = x$reference.group,
               baseline.reference = x$baseline.reference,
@@ -688,10 +743,10 @@ netcomb <- function(x,
               details.chkmultiarm = x$details.chkmultiarm,
               ##
               sep.trts = x$sep.trts,
-              nchar.trts = x$nchar.trts,
+              sep.comps = sep.comps,
+              nchar.comps = nchar.comps,
               ##
               inactive = inactive,
-              sep.comps = sep.comps,
               ##
               backtransf = x$backtransf,
               ##
