@@ -27,17 +27,18 @@
 #'   \code{"HR"}, \code{"MD"}, \code{"SMD"}, or \code{"ROM"}.
 #' @param level The level used to calculate confidence intervals for
 #'   individual comparisons.
-#' @param level.comb The level used to calculate confidence intervals
-#'   for pooled estimates.
-#' @param comb.fixed A logical indicating whether a fixed effects
-#'   (common effects) network meta-analysis should be conducted.
-#' @param comb.random A logical indicating whether a random effects
+#' @param level.ma The level used to calculate confidence intervals
+#'   for network estimates.
+#' @param fixed A logical indicating whether a fixed effects / common
+#'   effects network meta-analysis should be conducted.
+#' @param random A logical indicating whether a random effects
 #'   network meta-analysis should be conducted.
 #' @param prediction A logical indicating whether prediction intervals
 #'   should be printed.
 #' @param level.predict The level used to calculate prediction
 #'   intervals for a new study.
-#' @param reference.group Reference treatment.
+#' @param reference.group Reference treatment (first treatment is used
+#'   if argument is missing).
 #' @param baseline.reference A logical indicating whether results
 #'   should be expressed as comparisons of other treatments versus the
 #'   reference treatment (default) or vice versa. This argument is
@@ -62,7 +63,8 @@
 #'   design.
 #' @param tol.multiarm.se A numeric for the tolerance for consistency
 #'   of standard errors in multi-arm studies which are consistent by
-#'   design.
+#'   design. This check is not conducted if the argument is
+#'   \code{NULL}.
 #' @param details.chkmultiarm A logical indicating whether treatment
 #'   estimates and / or variances of multi-arm studies with
 #'   inconsistent results or negative multi-arm variances should be
@@ -76,13 +78,13 @@
 #'   example.
 #' @param nchar.trts A numeric defining the minimum number of
 #'   characters used to create unique treatment names (see Details).
+#' @param nchar.studlab A numeric defining the minimum number of
+#'   characters used to create unique study labels.
 #' @param n1 Number of observations in first treatment group.
 #' @param n2 Number of observations in second treatment group.
 #' @param event1 Number of events in first treatment group.
 #' @param event2 Number of events in second treatment group.
-#' @param incr Numerical value to each cell frequency.  # @param mean1
-#Mean in first treatment group.  # @param mean2 Mean in second
-#treatment group.
+#' @param incr Numerical value added to each cell frequency.
 #' @param sd1 Standard deviation in first treatment group.
 #' @param sd2 Standard deviation in second treatment group.
 #' @param time1 Person time at risk in first treatment group.
@@ -90,12 +92,16 @@
 #' @param title Title of meta-analysis / systematic review.
 #' @param keepdata A logical indicating whether original data (set)
 #'   should be kept in netmeta object.
-#' @param warn A logical indicating whether warnings should be printed
-#'   (e.g., if studies are excluded from meta-analysis due to zero
-#'   standard errors).
 #' @param control An optional list to control the iterative process to
 #'   estimate the between-study variance \eqn{\tau^2}. This argument
 #'   is passed on to \code{\link[metafor]{rma.mv}}.
+#' @param warn A logical indicating whether warnings should be printed
+#'   (e.g., if studies are excluded from meta-analysis due to zero
+#'   standard errors).
+#' @param warn.deprecated A logical indicating whether warnings should
+#'   be printed if deprecated arguments are used.
+#' @param nchar Deprecated argument (replaced by \code{nchar.trts}).
+#' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
 #' Network meta-analysis using R package \bold{netmeta} is described
@@ -188,15 +194,15 @@
 #' network meta-analysis.
 #' 
 #' Internally, both fixed effects and random effects models are
-#' calculated regardless of values choosen for arguments
-#' \code{comb.fixed} and \code{comb.random}. Accordingly, the network
-#' estimates for the random effects model can be extracted from
-#' component \code{TE.random} of an object of class \code{"netmeta"}
-#' even if argument \code{comb.random = FALSE}. However, all functions
-#' in R package \bold{netmeta} will adequately consider the values for
-#' \code{comb.fixed} and \code{comb.random}. E.g. function
+#' calculated regardless of values choosen for arguments \code{fixed}
+#' and \code{random}. Accordingly, the network estimates for the
+#' random effects model can be extracted from component
+#' \code{TE.random} of an object of class \code{"netmeta"} even if
+#' argument \code{random = FALSE}. However, all functions in R package
+#' \bold{netmeta} will adequately consider the values for \code{fixed}
+#' and \code{random}. E.g. function
 #' \code{\link{print.summary.netmeta}} will not print results for the
-#' random effects model if \code{comb.random = FALSE}.
+#' random effects model if \code{random = FALSE}.
 #' 
 #' By default, treatment names are not abbreviated in
 #' printouts. However, in order to get more concise printouts,
@@ -237,8 +243,8 @@
 #' \code{summary}, \code{forest}, and \code{netrank} functions. The
 #' object is a list containing the following components:
 #' \item{studlab, treat1, treat2, TE, seTE}{As defined above.}
-#' \item{seTE.adj}{Standard error of treatment estimate, adjusted for
-#'   multi-arm studies.}
+#' \item{seTE.adj.fixed, seTE.adj.random}{Standard error of treatment
+#'   estimate, adjusted for multi-arm studies.}
 #' \item{design}{Design of study providing pairwise comparison.}
 #' \item{n1, n2, event1, event2, incr}{As defined above.}
 ## \item{mean1, mean2, sd1, sd2, time1, time2}{As defined above.}
@@ -374,17 +380,18 @@
 #' \item{A.matrix}{Adjacency matrix (\emph{n}x\emph{n}).}
 #' \item{X.matrix}{Design matrix (\emph{m}x\emph{n}).}
 #' \item{B.matrix}{Edge-vertex incidence matrix (\emph{m}x\emph{n}).}
-#' \item{L.matrix}{Laplacian matrix (\emph{n}x\emph{n}).}
-#' \item{Lplus.matrix}{Moore-Penrose pseudoinverse of the Laplacian
-#'   matrix (\emph{n}x\emph{n}).}
+#' \item{L.matrix.fixed, L.matrix.random}{Laplacian matrix
+#'   (\emph{n}x\emph{n}).}
+#' \item{Lplus.matrix.fixed, Lplus.matrix.random}{Moore-Penrose
+#'   pseudoinverse of the Laplacian matrix (\emph{n}x\emph{n}).}
 #' \item{Q.matrix}{Matrix of heterogeneity statistics for pairwise
 #'   meta-analyses, where direct comparisons exist
 #'   (\emph{n}x\emph{n}).}
 #' \item{G.matrix}{Matrix with variances and covariances of
 #'   comparisons (\emph{m}x\emph{m}). G is defined as
 #'   \strong{BL+B^t}.}
-#' \item{H.matrix}{Hat matrix (\emph{m}x\emph{m}), defined as
-#'   \strong{H = GW = BL+B^tW}.}
+#' \item{H.matrix.fixed, H.matrix.random}{Hat matrix
+#'   (\emph{m}x\emph{m}), defined as \strong{H = GW = BL+B^tW}.}
 #' \item{n.matrix}{\emph{n}x\emph{n} matrix with number of
 #'   observations in direct comparisons (if arguments \code{n1} and
 #'   \code{n2} are provided).}
@@ -396,15 +403,15 @@
 #' \item{Cov.fixed}{Variance-covariance matrix (fixed effects model)}
 #' \item{Cov.random}{Variance-covariance matrix (random effects
 #'   model)}
-#' \item{sm, level, level.comb}{As defined above.}
-#' \item{comb.fixed, comb.random}{As defined above.}
+#' \item{sm, level, level.ma}{As defined above.}
+#' \item{fixed, random}{As defined above.}
 #' \item{prediction, level.predict}{As defined above.}
 #' \item{reference.group, baseline.reference, small.values,
 #'   all.treatments}{As defined above.}
 #' \item{seq, tau.preset, tol.multiarm, tol.multiarm.se}{As defined
 #'   above.}
 #' \item{details.chkmultiarm, sep.trts, nchar.trts}{As defined above.}
-#' \item{backtransf, title, warn}{As defined above.}
+#' \item{backtransf, title, warn, warn.deprecated}{As defined above.}
 #' \item{call}{Function call.}
 #' \item{version}{Version of R package netmeta used to create object.}
 #' 
@@ -433,7 +440,7 @@
 #' \bold{33}, 4353--69
 #' 
 #' Schwarzer G, Carpenter JR, Rücker G (2015):
-#' \emph{Meta-Analysis with R (Use-R!)}.
+#' \emph{Meta-Analysis with R (Use R!)}.
 #' Springer International Publishing, Switzerland
 #' 
 #' Senn S, Gavini F, Magrez D, Scheen A (2013):
@@ -453,7 +460,7 @@
 #' #
 #' net1 <- netmeta(TE, seTE, treat1, treat2, studlab,
 #'                 data = Senn2013, sm = "MD",
-#'                 comb.random = FALSE)
+#'                 random = FALSE)
 #' net1
 #' net1$Q.decomp
 #' 
@@ -466,7 +473,7 @@
 #' #
 #' net2 <- netmeta(TE, seTE, treat1, treat2, studlab,
 #'                 data = Senn2013, sm = "MD",
-#'                 comb.fixed = FALSE)
+#'                 fixed = FALSE)
 #' net2
 #' 
 #' # Change printing order of treatments with placebo last and use
@@ -475,9 +482,9 @@
 #' trts <- c("acar", "benf", "metf", "migl", "piog",
 #'           "rosi", "sita", "sulf", "vild", "plac")
 #' net3 <- netmeta(TE, seTE, treat1.long, treat2.long, studlab,
-#'                 data = Senn2013, sm = "MD", comb.fixed = FALSE,
+#'                 data = Senn2013, sm = "MD", fixed = FALSE,
 #'                 seq = trts, reference = "Placebo")
-#' print(summary(net3), digits = 2)
+#' print(net3, digits = 2)
 #' }
 #' 
 #' @export netmeta
@@ -488,9 +495,9 @@ netmeta <- function(TE, seTE,
                     data = NULL, subset = NULL,
                     sm,
                     level = gs("level"),
-                    level.comb = gs("level.comb"),
-                    comb.fixed = gs("comb.fixed"),
-                    comb.random = gs("comb.random") | !is.null(tau.preset),
+                    level.ma = gs("level.ma"),
+                    fixed = gs("fixed"),
+                    random = gs("random") | !is.null(tau.preset),
                     ##
                     prediction = FALSE,
                     level.predict = gs("level.predict"),
@@ -505,11 +512,12 @@ netmeta <- function(TE, seTE,
                     tau.preset = NULL,
                     ##
                     tol.multiarm = 0.001,
-                    tol.multiarm.se = tol.multiarm,
+                    tol.multiarm.se = NULL,
                     details.chkmultiarm = FALSE,
                     ##
                     sep.trts = ":",
                     nchar.trts = 666,
+                    nchar.studlab = 666,
                     ##
                     n1 = NULL,
                     n2 = NULL,
@@ -527,10 +535,12 @@ netmeta <- function(TE, seTE,
                     ##
                     title = "",
                     keepdata = gs("keepdata"),
-                    warn = TRUE,
+                    control = NULL,
                     ##
-                    control = NULL
-                    ) {
+                    warn = TRUE, warn.deprecated = gs("warn.deprecated"),
+                    ##
+                    nchar = nchar.trts,
+                    ...) {
 
 
   ##
@@ -538,38 +548,32 @@ netmeta <- function(TE, seTE,
   ## (1) Check arguments
   ##
   ##
-  chkchar <- meta:::chkchar
-  chklevel <- meta:::chklevel
-  chklogical <- meta:::chklogical
-  chknumeric <- meta:::chknumeric
-  ##
   chklevel(level)
-  chklevel(level.comb)
   chklevel(level.predict)
   ##
-  chklogical(comb.fixed)
-  chklogical(comb.random)
   chklogical(prediction)
   ##
+  missing.reference.group <- missing(reference.group)
   chklogical(baseline.reference)
   ##
-  small.values <- meta:::setchar(small.values, c("good", "bad"))
+  small.values <- setchar(small.values, c("good", "bad"))
   ##
   if (!is.null(all.treatments))
     chklogical(all.treatments)
   ##
-  method.tau <- meta:::setchar(method.tau, c("DL", "ML", "REML"))
+  method.tau <- setchar(method.tau, c("DL", "ML", "REML"))
   ##
   if (!is.null(tau.preset))
     chknumeric(tau.preset, min = 0, length = 1)
   ##
   chknumeric(tol.multiarm, min = 0, length = 1)
-  chknumeric(tol.multiarm.se, min = 0, length = 1)
+  if (!is.null(tol.multiarm.se))
+    chknumeric(tol.multiarm.se, min = 0, length = 1)
   chklogical(details.chkmultiarm)
   ##
   missing.sep.trts <- missing(sep.trts)
   chkchar(sep.trts)
-  chknumeric(nchar.trts, min = 1, length = 1)
+  chknumeric(nchar.studlab, length = 1)
   ##
   chklogical(backtransf)
   ##
@@ -577,20 +581,32 @@ netmeta <- function(TE, seTE,
   chklogical(keepdata)
   chklogical(warn)
   ##
-  ## Check value for reference group
-  ##
-  missing.reference.group <- missing(reference.group)
-  if (missing.reference.group)
-    reference.group <- ""
-  if (is.null(all.treatments))
-    if (reference.group == "")
-      all.treatments <- TRUE
-    else
-      all.treatments <- FALSE
-  ##
   chklogical(baseline.reference)
-
-
+  ##
+  ## Check for deprecated arguments in '...'
+  ##
+  args  <- list(...)
+  chklogical(warn.deprecated)
+  ##
+  level.ma <- deprecated(level.ma, missing(level.ma), args, "level.comb",
+                         warn.deprecated)
+  chklevel(level.ma)
+  ##
+  missing.fixed <- missing(fixed)
+  fixed <- deprecated(fixed, missing.fixed, args, "comb.fixed",
+                      warn.deprecated)
+  chklogical(fixed)
+  ##
+  random <-
+    deprecated(random, missing(random), args, "comb.random", warn.deprecated)
+  chklogical(random)
+  ##
+  nchar.trts <-
+    deprecated2(nchar.trts, missing(nchar.trts), nchar, missing(nchar),
+                warn.deprecated)
+  chknumeric(nchar.trts, min = 1, length = 1)
+  
+  
   ##
   ##
   ## (2) Read data
@@ -608,7 +624,7 @@ netmeta <- function(TE, seTE,
   TE <- eval(mf[[match("TE", names(mf))]],
              data, enclos = sys.frame(sys.parent()))
   ##
-  if (inherits(TE, "pairwise")) {
+  if (is.data.frame(TE) & !is.null(attr(TE, "pairwise"))) {
     is.pairwise <- TRUE
     ##
     sm <- attr(TE, "sm")
@@ -817,31 +833,31 @@ netmeta <- function(TE, seTE,
       data$.treat1[wo] <- data$.treat2[wo]
       data$.treat2[wo] <- ttreat1[wo]
       ##
-      if (meta:::isCol(data, ".n1") & meta:::isCol(data, ".n2")) {
+      if (isCol(data, ".n1") & isCol(data, ".n2")) {
         tn1 <- data$.n1
         data$.n1[wo] <- data$.n2[wo]
         data$.n2[wo] <- tn1[wo]
       }
       ##
-      if (meta:::isCol(data, ".event1") & meta:::isCol(data, ".event2")) {
+      if (isCol(data, ".event1") & isCol(data, ".event2")) {
         tevent1 <- data$.event1
         data$.event1[wo] <- data$.event2[wo]
         data$.event2[wo] <- tevent1[wo]
       }
       ##
-      ##if (meta:::isCol(data, ".mean1") & meta:::isCol(data, ".mean2")) {
+      ##if (isCol(data, ".mean1") & isCol(data, ".mean2")) {
       ##  tmean1 <- data$.mean1
       ##  data$.mean1[wo] <- data$.mean2[wo]
       ##  data$.mean2[wo] <- tmean1[wo]
       ##}
       ##
-      if (meta:::isCol(data, ".sd1") & meta:::isCol(data, ".sd2")) {
+      if (isCol(data, ".sd1") & isCol(data, ".sd2")) {
         tsd1 <- data$.sd1
         data$.sd1[wo] <- data$.sd2[wo]
         data$.sd2[wo] <- tsd1[wo]
       }
       ##
-      if (meta:::isCol(data, ".time1") & meta:::isCol(data, ".time2")) {
+      if (isCol(data, ".time1") & isCol(data, ".time2")) {
         ttime1 <- data$.time1
         data$.time1[wo] <- data$.time2[wo]
         data$.time2[wo] <- ttime1[wo]
@@ -942,10 +958,20 @@ netmeta <- function(TE, seTE,
       seq <- as.character(seq)
   }
   ##
+  ## Check value for reference group
+  ##
+  if (missing.reference.group)
+    reference.group <- labels[1]
+  if (is.null(all.treatments))
+    if (reference.group == "")
+      all.treatments <- TRUE
+    else
+      all.treatments <- FALSE
+  ##
   if (reference.group != "")
     reference.group <- setref(reference.group, labels)
-
-
+  
+  
   ##
   ##
   ## (4) Additional checks
@@ -957,10 +983,6 @@ netmeta <- function(TE, seTE,
   ##
   ## Check for correct number of comparisons
   ##
-  is.wholenumber <-
-    function(x, tol = .Machine$double.eps^0.5)
-      abs(x - round(x)) < tol
-  ##
   tabnarms <- table(studlab)
   sel.narms <- !is.wholenumber((1 + sqrt(8 * tabnarms + 1)) / 2)
   ##
@@ -1174,8 +1196,9 @@ netmeta <- function(TE, seTE,
                        p0$treat1.pos, p0$treat2.pos,
                        p0$narms, p0$studlab,
                        sm,
-                       level, level.comb,
-                       p0$seTE, sep.trts = sep.trts)
+                       level, level.ma,
+                       p0$seTE, 0, sep.trts,
+                       method.tau)
   ##
   trts <- rownames(res.f$A.matrix)
   ##
@@ -1275,10 +1298,10 @@ netmeta <- function(TE, seTE,
       ## Calculate Variance-Covariance matrix
       ##
       if (available.n &
-          (available.events | available.times |
-           (available.sds)))
-        ##(available.means & available.sds)))
+          (available.events | available.times | (available.sds))) {
+        dat.tau <- dat.tau[order(dat.tau$studlab), ]
         V <- bldiag(lapply(split(dat.tau, dat.tau$studlab), calcV, sm = sm))
+      }
       else
         V <- dat.tau$seTE^2
       ##
@@ -1302,8 +1325,9 @@ netmeta <- function(TE, seTE,
                        p1$treat1.pos, p1$treat2.pos,
                        p1$narms, p1$studlab,
                        sm,
-                       level, level.comb,
-                       p1$seTE, tau, sep.trts = sep.trts)
+                       level, level.ma,
+                       p1$seTE, tau, sep.trts,
+                       method.tau)
   ##
   TE.random <- res.r$TE.pooled
   seTE.random <- res.r$seTE.pooled
@@ -1347,6 +1371,8 @@ netmeta <- function(TE, seTE,
               TE = res.f$TE[o],
               seTE = res.f$seTE.orig[o],
               seTE.adj = res.f$seTE[o],
+              seTE.adj.fixed = res.f$seTE[o],
+              seTE.adj.random = res.r$seTE[o],
               ##
               design = designs$design[o],
               ##
@@ -1438,6 +1464,11 @@ netmeta <- function(TE, seTE,
               statistic.direct.random = res.r$statistic.direct,
               pval.direct.random = res.r$pval.direct,
               ##
+              Q.direct = res.r$Q.direct,
+              tau.direct = sqrt(res.r$tau2.direct),
+              tau2.direct = res.r$tau2.direct,
+              I2.direct = res.r$I2.direct,
+              ##
               TE.indirect.fixed = NA,
               seTE.indirect.fixed = NA,
               lower.indirect.fixed = NA,
@@ -1474,12 +1505,18 @@ netmeta <- function(TE, seTE,
               A.matrix = res.f$A.matrix,
               X.matrix = res.f$B.matrix[o, ],
               B.matrix = res.f$B.matrix[o, ],
-              L.matrix = res.f$L.matrix,
-              Lplus.matrix = res.f$Lplus.matrix,
+              ##
+              L.matrix.fixed = res.f$L.matrix,
+              Lplus.matrix.fixed = res.f$Lplus.matrix,
+              L.matrix.random = res.r$L.matrix,
+              Lplus.matrix.random = res.r$Lplus.matrix,
+              ##
               Q.matrix = res.f$Q.matrix,
               ##
-              G.matrix = res.f$G.matrix[o, o],
-              H.matrix = res.f$H.matrix[o, o],
+              G.matrix = res.f$G.matrix[o, o, drop = FALSE],
+              ##
+              H.matrix.fixed = res.f$H.matrix[o, o, drop = FALSE],
+              H.matrix.random = res.r$H.matrix[o, o, drop = FALSE],
               ##
               n.matrix = if (available.n) NA else NULL,
               events.matrix = if (available.events) NA else NULL,
@@ -1496,9 +1533,11 @@ netmeta <- function(TE, seTE,
               sm = sm,
               method = "Inverse",
               level = level,
-              level.comb = level.comb,
-              comb.fixed = comb.fixed,
-              comb.random = comb.random,
+              level.ma = level.ma,
+              fixed = fixed,
+              random = random,
+              comb.fixed = fixed,
+              comb.random = random,
               ##
               prediction = prediction,
               level.predict = level.predict,
@@ -1517,6 +1556,7 @@ netmeta <- function(TE, seTE,
               ##
               sep.trts = sep.trts,
               nchar.trts = nchar.trts,
+              nchar.studlab = nchar.studlab,
               ##
               backtransf = backtransf,
               ##
@@ -1548,6 +1588,8 @@ netmeta <- function(TE, seTE,
   res$comparisons <-
     names(res$prop.direct.random)[!is.zero(res$prop.direct.random)]
   ##
+  ## Add P.fixed and P.random
+  ##
   P.fixed <- P.random <- matrix(NA, n, n)
   colnames(P.fixed) <- rownames(P.fixed) <-
     colnames(P.random) <- rownames(P.random) <- trts
@@ -1711,6 +1753,9 @@ netmeta <- function(TE, seTE,
   ##
   if (method.tau %in% c("ML", "REML")) {
     res$.metafor <- rma1
+    res$.dat.tau <- dat.tau
+    res$.V <- V
+    res$.formula.trts <- formula.trts
     res$version.metafor <- packageDescription("metafor")$Version
   }
   
